@@ -5,24 +5,21 @@
 #   All rights reserved. Copyright (c) 2017 - 2024 VECTIONEER.
 #
 
-import os
 import itertools
-
 import robot_control
-from robot_control import motionSL_pb2
 from robot_control.system_defs import FrameTypes
 
 
 def sendProgramList(req, motorcortex_types, motion_programs, systems_id):
     """Sends programs to the multiple systems
 
-    Args:
-        req(motorcortex.Request): reference to a Request instance
+        Args:
+            req(motorcortex.Request): reference to a Request instance
             motorcortex_types(motorcortex.MessageTypes): reference to a MessageTypes instance
-            motion_programs(list MotionProgram): a list of motion programs
+            motion_programs(list(MotionProgram)): a list of motion programs
             systems_id(list(int)): a list of systems id
+    """
 
-"""
     MotionSpec = motorcortex_types.getNamespace("motion_spec_v1")
     motion_program_list = MotionSpec.MotionProgramList()
 
